@@ -1,8 +1,12 @@
 c            hadronic collision parameters 
 c	(->  ---------------------------------------------
 
-        real*8  Cepic0  !2  Charge exchange prob. of pi+- --> pi0
-        real*8  Cekaon  !2  Charge exchange prob. of kaon k+- -> k0
+        real*8  Cepic0  !2  Obsolute
+        real*8  Cekaon  !2  Obsolute
+        integer SucInt  !2  The number of successive interactions inside A is affected by this parameter.
+                        !   If 0--> old one (before uv3.500) is used, which give rather smaller number 
+                        !   (<Nsuc> in Air = 1.7 for 30 mb pp), if 1--> new one <Nsuc>=2.2 for 30 mb pp).
+                        !   Default is 1.  
         real*8  Ceneuc  !2  p -> n ; n-> p; p~->n~; n~->p~ prob.
         real*8  Mudirp  !2  DD~ # enhancement factor. D is only for prompt muon.
      	real*8  Kpilog  !2  k-ch/pi-ch=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= effective s.
@@ -41,7 +45,7 @@ c	<-)     -----------------------------
  
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
-     *         LundPara(10)
+     *         LundPara(10), SucInt
         common /Zevhnc/ IntModel 
 c                 this should be in block common. 
 c        data  Cepic0/0.3d0/, Cekaon/0.d0/, Ceneuc/0.35d0/,
