@@ -1,3 +1,4 @@
+#include "chookHybAS.f"
 #include "ctemplCeren.f"
 #include "ZcosmosBD.h"
 c  *************************************** hook for Beginning of a Run
@@ -8,13 +9,15 @@ c  *
       subroutine chookBgRun
       implicit none
 #include "Zmanagerp.h"
-#include "Zcode.h"
-#include "Zptcl.h"
-      record /ptcl/ temp
+
 c          ///////////
-      common /testcos/sumg, ng, nth, nev
-      real*8 sumg
-      integer ng, nth, nev
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth(nth)
 c     //////////////
 
 c         If you feel writing the parameters on stderr is
@@ -27,8 +30,6 @@ c         Also you may comment out all output routines below.
 
       ieeer = ieee_handler('set', 'invalid', csigHandler)
 #endif
-      call cmkptc(kkaon, 0, 0, temp)
-      write(*,*)  temp.code, temp.subcode
 
 c
 c            namelist output
@@ -37,8 +38,22 @@ c            primary information
       call cprintPrim(ErrorOut)
 c            observation level information
       call cprintObs(ErrorOut)
-      nth = 0
-      nev = 0
+
+      eth(1) = 0.3d-3
+      eth(2) = 0.5d-3
+      eth(3)=  1.d-3
+      eth(4) = 2.d-3
+      eth(5) = 5.d-3
+      eth(6) = 10.d-3
+      eth(7) = 20.d-3
+      eth(8)=  50.d-3
+      eth(9) = 100.d-3
+      eth(10) = 200.d-3
+      eth(11) = 500.d-3
+      eth(12) = 1.d0
+c      ////////////
+      ntha = 1  !  for each ptcle out put use only 1 threshold
+c     /////////////
       end
 #ifdef sun4
       integer function csigHandler(sig, code, context)
@@ -57,22 +72,70 @@ c     *  After this is executed, event generation starts.
 c     *
       subroutine chookBgEvent
       implicit none
+#include "Ztrack.h"
+#include "Zmanagerp.h"
+
 c          ///////////
-      common /testcos/sumg, ng, nth, nev
-      real*8 sumg
-      integer ng, nth, nev
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth(nth)
 c     //////////////
+
+
+
+
+      record /track/ inci
+      record /coord/ angle
+
+      integer  nev
+c     //////////////
+      integer i, j
       integer seed(2)
 c      write(*, *) ' bigin event generation'
       call cqIniRn(seed)
 c      write(*,*) ' seed=', seed
 c      call cwriteSeed
-      sumg = 0.
-      ng = 0
-      nev = nev + 1
+      do i = 1, nl
+         do j = 1, ntha
+            ng(j, i) = 0
+            ne(j, i) = 0
+            nh(j, i) = 0
+            nmu(j, i) = 0
+         enddo
+      enddo
+      write(*, *)
+      call cqIncident(inci, angle)
+      write(*,*) EventNo, inci.p.code, inci.p.fm.e, -angle.r(1),
+     *   -angle.r(2), -angle.r(3)      
       end
-  
+      subroutine ccount(nc, aTrack)
+      implicit none
+#include "Zcode.h"
+#include "Ztrack.h"
 
+      record /track/ aTrack
+      integer i
+c          ///////////
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl),
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth(nth)
+c
+      integer nc(nth, nl)
+
+      do i = 1, ntha
+        if( aTrack.p.fm.e- aTrack.p.mass .lt. eth(i)) goto 10
+        nc(i, aTrack.where) =  nc(i, aTrack.where) + 1
+      enddo
+ 10   continue 
+      end
 c     ************************************ hook for observation
 c     *  One particel information is brought here by the system.
 c     *  All information of the particle is in aTrack
@@ -87,23 +150,29 @@ c
       implicit none
 #include "Zcode.h"
 #include "Ztrack.h"
+#include  "Zheavyp.h"
       integer id  ! input.  1 ==> aTrack is going out from
 c                                 outer boundery.
 c                           2 ==> reached at an observation level
 c                           3 ==> reached at inner boundery.
       record /track/ aTrack
+      record /track/ inci
       record /coord/ angle, tetafai
-
-c     //////////////
-
-
+c      integer i
+c          ///////////
 
 c          ///////////
-      common /testcos/sumg, ng, nth, nev
-      real*8 sumg
-      character*8 ptclid
-      integer ng, nth, nev, iij
-c//////////////
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth(nth)
+c     //////////////
+
+      integer iij
+
 
 
 c
@@ -111,32 +180,56 @@ c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
 c      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
-      if(id .eq. 3 .or. id .eq. 2) then
-c          iij = aTrack.p.code  
+       if( id .eq. 2) then
+           iij = aTrack.p.code  
 c          call cgpid(iij, ptclid)
-c      if(id .eq. 2 .and. aTrack.p.code .eq. kelec ) then
+           if(iij .eq. kelec ) then
+c     call cqIncident(inci, angle)
+              call ccount(ne, aTrack)
+c              ne(aTrack.where) = ne(aTrack.where) + 1
+           elseif(iij  .eq. kphoton ) then
+              call ccount(ng, aTrack)
+c              ng(aTrack.where) = ng(aTrack.where) + 1
+           elseif(iij .eq. kmuon ) then
+              call ccount(nmu, aTrack)
+c              nmu(aTrack.where) = nmu(aTrack.where) + 1
+           elseif( iij .eq. kpion  .or. iij .eq.  kkaon .or. 
+     *        iij .eq. knuc) then
+              if(aTrack.p.charge .ne. 0 ) then
+                 call ccount(nh, aTrack)
+c                 nh(aTrack.where) = nh(aTrack.where) + 1
+              endif
+           endif
+        endif
+
 c            output typical quantities.
-         call cqIncident(inci, angle)
-          write(*, *) id,  nev, 
-     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
-c     *  aTrack.p.code, " ", ptclid,    !  ptcl code.  integer*2.
-     *  aTrack.p.code,
-c     *  aTrack.p.charge,  !  charge,  integer*2 
-c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
+c         id .eq. 2 below  if want otuput
+        if(id .eq. 2 .and. aTrack.where .eq.  8 ) then
+         if(aTrack.p.code .ne. kneue .and. aTrack.p.code .ne. 
+     *    kneumu) then
+       write(*,
+     *  '(i2,1x,i2,1x,f12.2, g13.4, f12.2,1x, f12.2,1x,f7.4,i3)')
+c     * nev, 
+c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
+     *  aTrack.p.code,  ! " ", ptclid,    !  ptcl code.  integer*2.
+     *  aTrack.p.charge,  !  charge,  integer*2 
+     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
 c                        !  if TimeStructure is F, nonsense.
-     *  sngl(aTrack.p.fm.e), ! total energy in GeV.
-     *  sngl(-angle.r(3))
-c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y)  !  x, y in m
+     *  sngl(aTrack.p.fm.e), !  - aTrack.p.mass), ! kinetic energy in GeV
+     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y),  !  x, y in m
 c     *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.y),  ! direc. cos.y
 c     *  sngl(aTrack.vec.w.z),  ! direc. cos.z
-c     *  sngl(aTrack.vec.coszenith) ! cos of zenith angle
+c     * sngl(-angle.r(3)) ,
+     * sngl(aTrack.vec.coszenith),  ! cos of zenith angle
+c     * sngl(inci.p.fm.p(4)-inci.p.mass)/Code2massN(int(inci.p.code)),
+c     * inci.p.code
 c         if(aTrack.p.code .eq. kelec) then
 c            write(*, *) aTrack.where
 c         endif
 c      endif
 c         you may need in some case other information such as
-c       aTrack.p.subcode   ! sub code of the particle integer*2
+     *  aTrack.p.subcode   ! sub code of the particle integer*2
 c       aTrack.p.mass      ! mass 
 c       aTrack.wgt         ! weight of the particle (may not be 1. if
 c                           ! ThinSampling =T)
@@ -145,10 +238,11 @@ c                            given in the  Earth xyz system.
 
 c       aTrack.p.fm.y      !          y
 c       aTrack.p.fm.z      !          z
-        if(aTrack.p.code .eq. kelec .or. aTrack.p.code .eq. kphoton) 
-     *     then
-           ng = ng+1
-           sumg = sumg + aTrack.p.fm.e
+c        if(aTrack.p.code .eq. kelec .or. aTrack.p.code .eq. kphoton) 
+c     *     then
+c           ng = ng+1
+c           sumg = sumg + aTrack.p.fm.e
+
         endif
       endif
       end
@@ -170,12 +264,21 @@ c    *
 
       record /track/ inci
       record /coord/ angle, tetafai
-      integer i
+      integer i, j
+
+c          ///////////
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth(nth)
+c     //////////////
+
+
 
 c          ///////////
-      common /testcos/sumg, ng, nth, nev
-      real*8 sumg
-      integer ng, nth, nev
       real*8  fdepth, bsin, teta, fai, sumsize
       real*8  cgetBsin
 c     //////////////
@@ -198,12 +301,23 @@ c         write(*, *) (ASObsSites(i).esize, i=1, NoOfASSites)
 c                   size weighted age
 c         write(*, *) (ASObsSites(i).age,   i=1, NoOfASSites) 
          sumsize = 0.
-         do i = 1, NoOfASSites
-            sumsize = sumsize + ASObsSites(i).esize
-             write(*, *)  sngl(ASObsSites(i).pos.depth),
+         write(*, *)
+        do j = 1, ntha
+          if(ntha .gt. 1) then
+             write(*,*) j
+          endif
+           do i = 1, NoOfASSites
+              sumsize = sumsize + ASObsSites(i).esize
+               write(*, '(f7.1,g13.3,f8.3,f7.1,
+     *             4i8,f7.4)')
+c     *       f8.3,    g13.3,f10.3,f10.3) ')
+c     *           sngl(ASObsSites(i).pos.depth/10./angle.r(3)),
+     *           sngl(ASObsSites(i).pos.depth/10.),
      *           sngl(ASObsSites(i).esize), 
      *           sngl(ASObsSites(i).age), sngl(fdepth),
-     *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)  
+c     *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)  
+     *           ne(j, i), nmu(j, i), nh(j, i), ng(j, i), eth(j)
+            enddo
          enddo
       endif
 c      write(*, *)
@@ -356,6 +470,8 @@ c        IntInfArray(ProcessNo).process  will have
 c             'col' or 'decay'
       end
 
+      
+
 
 
 
