@@ -77,6 +77,7 @@ c -------------------------------------tracking a ptcl
 #include  "Zobs.h"
 #include  "Zobsv.h"
 #include  "Zincidentv.h"
+#include  "Zcode.h"
 
 c                next is for DEBUG
 #include  "Zcondc.h"
@@ -107,7 +108,6 @@ c           mag. deflection.  Path end inf is set in MovedTrack
 #if DEBUG == 1
          call checkstat('after ccompPathEnd')
 #endif
-
 c           see if MovedTrack crosses an observation site.
 c         (or reaches BorderHeightL)  If so, reset MovedTrack. 
             call cifXObsSite
@@ -120,8 +120,24 @@ c         (or reaches BorderHeightL)  If so, reset MovedTrack.
          endif
 c     
          if(MoveStat .eq. Truncated) then
-c             stack current ptcl
-            call cpush(MovedTrack)
+c           see if truncation is really ok.  for energy = 0, 
+c           if anti ptcl, it should be anihilated, if decayabl,
+c           it should be decayed.
+            if(MovedTrack.p.fm.p(4) .eq. MovedTrack.p.mass) then
+               if(MovedTrack.p.subcode .eq. antip) then
+                  MoveStat = ToInteract
+               elseif(MovedTrack.p.code .eq. kmuon) then
+                  MoveStat = ToInteract
+               elseif(MovedTrack.p.code .eq. kpion) then
+                  MoveStat = ToInteract
+               elseif(MovedTrack.p.code .eq. kkaon) then
+                  MoveStat = ToInteract
+               endif
+            endif
+         endif 
+         if(MoveStat .eq. Truncated) then
+c              stack current ptcl
+              call cpush(MovedTrack)
          elseif(MoveStat .eq. ToInteract ) then
             if(Zfirst .eq. 0.) then
                Zfirst = MovedTrack.pos.depth
@@ -315,6 +331,7 @@ c     **************************** cfixProc **********
 #include  "Ztrackv.h"
 #include  "Zearth.h"
 
+
       real*8 h, leng, t, minlen, clen2thick
 c     
       integer i, jcut
@@ -326,8 +343,13 @@ c              get vertical height
        do i = 1, NumberOfInte
          if(.not. IntInfArray(i).decay) then
 c              convert kg/m2 into length
-            call cthick2len(h, TrackBefMove.vec.coszenith, 
-     *           IntInfArray(i).thickness, leng, t, jcut)
+            if(NumberOfInte .eq. 1 .or.
+     *        IntInfArray(i).thickness .ne. Infty) then
+               call cthick2len(h, TrackBefMove.vec.coszenith, 
+     *         IntInfArray(i).thickness, leng, t, jcut)
+            else
+               leng = Infty
+            endif
          else
             leng = IntInfArray(i).length
             jcut = 0
@@ -344,7 +366,6 @@ c              convert kg/m2 into length
                minlen = leng
          endif
       enddo
-
       if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
          IntInfArray(ProcessNo).thickness = clen2thick(h, 
      *      TrackBefMove.vec.coszenith, 
@@ -370,4 +391,3 @@ c
          IntInfArray(ProcessNo).thickness  = thick
       endif
       end
-
